/*
--------------------------------------------------------------------------------
  program:   tetra.sas
  purpose:   This SAS program demonstrates factor analysis of 
             tetrachoric correlation coefficients.

             Here the tetrachoric correlation matrix is read
             from an external file produced by TetMat.

 written:    14 august 2006

 notes:      user supplies information in first three program lines below
--------------------------------------------------------------------------------
*/

/***** Supply path and filename for raw data, and no. of vars. ******/

%let path  = c:\tetmat\examples\; 
%let file  = matrix.txt;
%let nvars = 5;


* set output line width to 80 columns, nocenter, and first page = 1;

options nocenter pageno=1 ls=80 ;

* clear the Display Manager log and output ;

dm 'clear output';
dm 'clear log';

title  'Factor Analysis of Tetrachoric Correlation Coefficients';
title2 'LSAT6 Data (Bock & Lieberman, 1970)';


*  ------------------------------------------------------ ; 
*  Read a matrix of tetrachoric correlation coefficients  ;
*  from a file and store as a SAS correlation data set    ;
*  (refer to SAS manual under PROC CORR for details)      ; 
*  ------------------------------------------------------ ; 

data one (type=corr); 
   length _name_ $4; 

*  use values assigned to path and file above;

   infile "&path&file";

   *  in a SAS correlation data set, each matrix row ; 
   *  is preceded by the variables _type_ and _name_ ; 

   _type_='corr'; 

   *  here we name the variables v1, v2, ... v<nvars> ; 

   _name_='v' || left(put(_n_, best.)); 

   *  input the data ;

   input v1-v&nvars; 

run; 


* ---------------------- ;
* Do the factor analysis ;
* ---------------------- ;

title3  '1-Common Factor Model - ULS Estimation';

proc factor
   data   = one
   method = uls
   n      = 1
   nobs = 1000
   ;
run;

/* 
----------------------------------------------------------------------
   Notes:  Other generally useful options are
   
      scree      (produce scree plot of eigenvalues)
      rotate = v (varimax rotation)
      reorder    (list variables by strength of loading per factor)
----------------------------------------------------------------------
*/
